summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorCaolán McNamara <caolan.mcnamara@collabora.com>2023-09-29 12:12:10 +0100
committerCaolán McNamara <caolan.mcnamara@collabora.com>2023-09-29 14:14:39 +0200
commitef5cb6cdcd50942aea56ffb322bc89a4c7069bc6 (patch)
tree26533b692a7f126c0d94aac7e48648b64265b996 /include
parentb409fb0eba05b6b6d78156499210aa75a9cfc14c (diff)
make FunctionBasedURPConnection simpler
and leave it to the client how it wants to read/provide the data Change-Id: Ibd4d967b79a699c96d1ea8529544b585a97cc0c8 Reviewed-on: https://gerrit.libreoffice.org/c/core/+/157405 Tested-by: Jenkins Reviewed-by: Caolán McNamara <caolan.mcnamara@collabora.com>
Diffstat (limited to 'include')
-rw-r--r--include/LibreOfficeKit/LibreOfficeKit.h6
-rw-r--r--include/LibreOfficeKit/LibreOfficeKit.hxx20
2 files changed, 13 insertions, 13 deletions
diff --git a/include/LibreOfficeKit/LibreOfficeKit.h b/include/LibreOfficeKit/LibreOfficeKit.h
index 5e77e30549d0..96d6a3d3aca7 100644
--- a/include/LibreOfficeKit/LibreOfficeKit.h
+++ b/include/LibreOfficeKit/LibreOfficeKit.h
@@ -133,10 +133,10 @@ struct _LibreOfficeKitClass
void (*trimMemory) (LibreOfficeKit* pThis, int nTarget);
/// @see lok::Office::startURP
- int (*startURP)(LibreOfficeKit* pThis, void* pReceiveURPFromLOContext,
- void** ppSendURPToLOContext,
+ void* (*startURP)(LibreOfficeKit* pThis,
+ void* pReceiveURPFromLOContext, void* pSendURPToLOContext,
int (*fnReceiveURPFromLO)(void* pContext, const signed char* pBuffer, int nLen),
- int (**pfnSendURPToLO)(void* pContext, const signed char* pBuffer, int nLen));
+ int (*fnSendURPToLO)(void* pContext, signed char* pBuffer, int nLen));
/// @see lok::Office::stopURP
void (*stopURP)(LibreOfficeKit* pThis, void* pSendURPToLOContext);
diff --git a/include/LibreOfficeKit/LibreOfficeKit.hxx b/include/LibreOfficeKit/LibreOfficeKit.hxx
index ff3974417c69..c06d2f6d6619 100644
--- a/include/LibreOfficeKit/LibreOfficeKit.hxx
+++ b/include/LibreOfficeKit/LibreOfficeKit.hxx
@@ -1171,26 +1171,26 @@ public:
* Start a UNO acceptor using the function pointers provides to read and write data to/from the acceptor.
*
* @param pReceiveURPFromLOContext A pointer that will be passed to your fnRecieveURPFromLO function
- * @param ppSendURPToLOContext A pointer to a pointer that you should give to the function passing URP to LO will be stored in this.
+ * @param pSendURPToLOContext A pointer that will be passed to your fnSendURPToLO function
* @param fnReceiveURPFromLO A function pointer that LO should use to pass URP back to the caller
* @param pfnSendURPToLO A function pointer pointer that the caller should use to pass URP to LO will be stored in this.
*/
- bool startURP(void* pReceiveURPFromLOContext, void** ppSendURPToLOContext,
- int (*fnReceiveURPFromLO)(void* pContext, const signed char* pBuffer, int nLen),
- int (**pfnSendURPToLO)(void* pContext, const signed char* pBuffer, int nLen))
+ void* startURP(void* pReceiveURPFromLOContext, void* pSendURPToLOContext,
+ int (*fnReceiveURPFromLO)(void* pContext, const signed char* pBuffer, int nLen),
+ int (*fnSendURPToLO)(void* pContext, signed char* pBuffer, int nLen))
{
- return mpThis->pClass->startURP(mpThis, pReceiveURPFromLOContext, ppSendURPToLOContext,
- fnReceiveURPFromLO, pfnSendURPToLO);
+ return mpThis->pClass->startURP(mpThis, pReceiveURPFromLOContext, pSendURPToLOContext,
+ fnReceiveURPFromLO, fnSendURPToLO);
}
/**
* Stop a function based URP connection you previously started with startURP
*
- * @param pSendURPToLOContext the context you got back in the ppSendURPToLOContext argument when starting the connection
+ * @param pURPContext the context returned by startURP when starting the connection
*/
- void stopURP(void* pSendURPToLOContext)
+ void stopURP(void* pURPContext)
{
- mpThis->pClass->stopURP(mpThis, pSendURPToLOContext);
+ mpThis->pClass->stopURP(mpThis, pURPContext);
}
};
@@ -1171,26 +1171,26 @@ public:
* @param fnReceiveURPFromLO A function pointer that LO should use to pass URP back to the caller
- * @param pfnSendURPToLO A function pointer pointer that the caller should use to pass URP to LO will be stored in this.
+ * @param fnSendURPToLO A function pointer pointer that the caller should use to pass URP to LO
*/